.. raw:: html
    <head>
        <meta http-equiv='refresh' content='0; URL=./index.html#use-specialized-uis-and-apis'>
    </head>

# Use specialized UIs and APIs

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

Build a sequential UI<pipeline/index>
Build custom components<custom_components/index>
Explicitly link parameters (Callbacks API)<links/index>
Generate UIs from declared parameters (Declarative API)<param/index>
```
